/*
 * Copyright (c) 2000 Phil Thompson (phil@river-bank.demon.co.uk)
 *
 * The interface to the VPValue, VPValueDict and VPValueList types.
 */


#ifndef VPVALUE_H
#define VPVALUE_H

#include <Python.h>
#include <gtk/gtkobject.h>

#ifdef __cplusplus
extern "C" {
#endif


/*****************************************************************************/
/* VPValue                                                                   */
/*****************************************************************************/

#define	VP_VALUE(o)		GTK_CHECK_CAST((o),vp_value_get_type(),VPValue)
#define	VP_VALUE_CLASS(c)	GTK_CHECK_CLASS_CAST((c),vp_value_get_type(),VPValueClass)
#define	VP_IS_VALUE(o)		GTK_CHECK_TYPE((o),vp_value_get_type())


/* The contents of this are kept private. */
 
struct pylibContext;


/* The instance structure. */

typedef struct
{
	GtkObject		object;
	struct pylibContext	*context;	/* The context. */
	PyObject		*pyobj;		/* The Python object. */
} VPValue;


/* The class structure. */

typedef struct {
	GtkObjectClass	object_class;
} VPValueClass;


guint vp_value_get_type(void);
GtkObject *vp_value_new_string(const char *,GtkObject *);
GtkObject *vp_value_new_long(long,GtkObject *);
GtkObject *vp_value_new_double(double,GtkObject *);


/*****************************************************************************/
/* VPValueDict                                                               */
/*****************************************************************************/

#define	VP_VALUEDICT(o)		GTK_CHECK_CAST((o),vp_valuedict_get_type(),VPValueDict)
#define	VP_VALUEDICT_CLASS(c)	GTK_CHECK_CLASS_CAST((c),vp_valuedict_get_type(),VPValueDictClass)
#define	VP_IS_VALUEDICT(o)	GTK_CHECK_TYPE((o),vp_valuedict_get_type())


/* The instance structure. */

typedef struct
{
	VPValue		value;
} VPValueDict;


/* The class structure. */

typedef struct {
	VPValueClass	parent_class;
} VPValueDictClass;


guint vp_valuedict_get_type(void);
GtkObject *vp_valuedict_new(GtkObject *);
void vp_valuedict_set(GtkObject *,GtkObject *,GtkObject *);


/*****************************************************************************/
/* VPValueList                                                               */
/*****************************************************************************/

#define	VP_VALUELIST(o)		GTK_CHECK_CAST((o),vp_valuelist_get_type(),VPValueList)
#define	VP_VALUELIST_CLASS(c)	GTK_CHECK_CLASS_CAST((c),vp_valuelist_get_type(),VPValueListClass)
#define	VP_IS_VALUELIST(o)	GTK_CHECK_TYPE((o),vp_valuelist_get_type())


/* The instance structure. */

typedef struct
{
	VPValue		value;
} VPValueList;


/* The class structure. */

typedef struct {
	VPValueClass	parent_class;
} VPValueListClass;


guint vp_valuelist_get_type(void);
GtkObject *vp_valuelist_new(GtkObject *);
void vp_valuelist_append(GtkObject *,GtkObject *);


#ifdef __cplusplus
}
#endif

#endif
