#!/usr/bin/env vpshell

# This script demonstrates the different chart types.


# Create the GUI.

def createGUI(aw):
    width = 180
    height = 180

    # Arrange the charts in a grid.

    vb = vp.Grid(aw)

    # Create the different data series.

    pieSeries = [vp.PieSlice(value = 10.0, color = vp.Color.darkRed),
		     vp.PieSlice(value = 16.0, color = vp.Color.darkGreen),
		     vp.PieSlice(value = 20.0, color = vp.Color.darkBlue)]

    series1 = vp.GraphSeries(color = vp.Color.cyan,
			values = [4.5, 6.8, 3.4, 2.0, None, 0.5,
				  1.8, 6.5, 8.8, 6.0, 7.2, 6.5])

    series2 = vp.GraphSeries(color = vp.Color.magenta,
			values = [1.4, 3.8, 3.1, 7.6, 6.5, 8.1,
				  5.3, None, 3.3, 4.5, 2.2, 3.5])

    hlcSeries = vp.GraphSeries(color = vp.Color.white,
			values = [(5.0,1.2,2.0), (7.2,4.3,6.8), (6.3,0.2,1.0),
				  (9.2,5.6,6.5), (6.3,2.2,2.2), (4.7,4.5,0.7),
				  (3.4,2.5,3.0), (4.7,3.5,2.8), (7.3,3.5,4.3),
				  (8.4,4.5,6.6), (9.3,5.4,7.2), (5.8,1.3,3.4)])

    comboSeries = vp.GraphSeries(color = vp.Color.darkGreen,
			values = [4.5, 5.8, 3.4, 5.5, 7.2, 6.5,
				  9.4, 8.5, 5.9, 6.3, 4.2, 2.3])

    labels = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
              'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']

    # Create and plot each chart.

    chart1 = vp.PieChart(vb,
			row = 0, column = 0,
			height = height, width = width,
			title = '2D Pie Chart',
			series = pieSeries)

    chart1.plot()

    chart2 = vp.Graph(vb,
			graphType = vp.Graph.Bar,
			row = 0, column = 1,
			height = height, width = width,
			labels = labels,
			title = '2D Bar Graph',
			series = [series1, series2])

    chart2.plot()

    chart3 = vp.Graph(vb,
			graphType = vp.Graph.Area,
			row = 0, column = 2,
			height = height, width = width,
			labels = labels,
			title = '2D Area Graph',
			series = [series1, series2])

    chart3.plot()

    chart4 = vp.Graph(vb,
			graphType = vp.Graph.Line,
			row = 0, column = 3,
			height = height, width = width,
			labels = labels,
			title = '2D Line Graph',
			series = [series1, series2])

    chart4.plot()

    chart5 = vp.Graph(vb,
			graphType = vp.Graph.HLC,
			row = 0, column = 4,
			height = height, width = width,
			labels = labels,
			title = '2D HLC Graph',
			series = [hlcSeries])

    chart5.plot()

    chart6 = vp.Graph(vb,
			graphType = vp.Graph.LineAndBar,
			row = 0, column = 5,
			height = height, width = width,
			labels = labels,
			title = '2D Line and Bar Graph',
			series = [series1],
			comboSeries = comboSeries)

    chart6.plot()

    chart7 = vp.Graph(vb,
			graphType = vp.Graph.LineAndArea,
			row = 1, column = 0,
			height = height, width = width,
			labels = labels,
			title = '2D Line and Area Graph',
			series = [series1],
			comboSeries = comboSeries)

    chart7.plot()

    chart8 = vp.Graph(vb,
			graphType = vp.Graph.HLCAndBar,
			row = 1, column = 1,
			height = height, width = width,
			labels = labels,
			title = '2D HLC and Bar Graph',
			series = [hlcSeries],
			comboSeries = comboSeries)

    chart8.plot()

    chart9 = vp.Graph(vb,
			graphType = vp.Graph.HLCAndArea,
			row = 1, column = 2,
			height = height, width = width,
			labels = labels,
			title = '2D HLC and Area Graph',
			series = [hlcSeries],
			comboSeries = comboSeries)

    chart9.plot()

    chart10 = vp.Graph(vb,
			graphType = vp.Graph.Bar3D,
			row = 1, column = 3,
			height = height, width = width,
			labels = labels,
			title = '3D Bar Graph',
			series = [series1, series2])

    chart10.plot()

    chart11 = vp.Graph(vb,
			graphType = vp.Graph.Area3D,
			row = 1, column = 4,
			height = height, width = width,
			labels = labels,
			title = '3D Area Graph',
			series = [series1, series2])

    chart11.plot()

    chart12 = vp.Graph(vb,
			graphType = vp.Graph.Line3D,
			row = 1, column = 5,
			height = height, width = width,
			labels = labels,
			title = '3D Line Graph',
			series = [series1, series2])

    chart12.plot()

    chart13 = vp.Graph(vb,
			graphType = vp.Graph.HLC3D,
			row = 2, column = 0,
			height = height, width = width,
			labels = labels,
			title = '3D HLC Graph',
			series = [hlcSeries])

    chart13.plot()

    chart14 = vp.Graph(vb,
			graphType = vp.Graph.LineAndBar3D,
			row = 2, column = 1,
			height = height, width = width,
			labels = labels,
			title = '3D Line and Bar Graph',
			series = [series1],
			comboSeries = comboSeries)

    chart14.plot()

    chart15 = vp.Graph(vb,
			graphType = vp.Graph.LineAndArea3D,
			row = 2, column = 2,
			height = height, width = width,
			labels = labels,
			title = '3D Line and Area Graph',
			series = [series1],
			comboSeries = comboSeries)

    chart15.plot()

    chart16 = vp.Graph(vb,
			graphType = vp.Graph.HLCAndBar3D,
			row = 2, column = 3,
			height = height, width = width,
			labels = labels,
			title = '3D HLC and Bar Graph',
			series = [hlcSeries],
			comboSeries = comboSeries)

    chart16.plot()

    chart17 = vp.Graph(vb,
			graphType = vp.Graph.HLCAndArea3D,
			row = 2, column = 4,
			height = height, width = width,
			labels = labels,
			title = '3D HLC and Area Graph',
			series = [hlcSeries],
			comboSeries = comboSeries)

    chart17.plot()


aw = vp.ApplicationWindow()
createGUI(aw)
